==> libcamera-docs-0.6.0-2-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "libcamera", "index.html", [
    [ "libcamera internal API reference", "index.html", null ],
    [ "Reentrancy and Thread-Safety", "thread-safety.html", null ],
    [ "Thread Support", "thread.html", [
      [ "Threads and Objects", "thread.html#thread-objects", null ],
      [ "Threads and Signals", "thread.html#thread-signals", null ]
    ] ],
    [ "Camera Model", "camera-model.html", [
      [ "Pipeline Model", "camera-model.html#camera-pipeline-model", [
        [ "Camera Sensor Model", "camera-model.html#camera-sensor-model", null ],
        [ "Digital Zoom", "camera-model.html#digital-zoom", null ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ],
    [ "Thread Safety", "context.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"af_8h.html",
"classlibcamera_1_1CameraManager.html",
"classlibcamera_1_1ControlInfoMap.html#add3c18c2f5796516dada423befcd29c5",
"classlibcamera_1_1DebayerCpu.html#a2ed0021813e3ca42fd945b7804f471ca",
"classlibcamera_1_1File.html#a6df7f0036263a0a04610e586e9e604cba131fb182a881796e7606ed6da27f1197",
"classlibcamera_1_1IPCUnixSocket.html#a9c11dc2c41bc3e3047d66f37bd6f84a6",
"classlibcamera_1_1MediaObject.html#a040304e6607c1742fa50a1cfbe1064a5",
"classlibcamera_1_1Process.html#a1898dc069d405275d1c6761731a48fad",
"classlibcamera_1_1Size.html#a0063ea1917eeaa0b34a4cf21507dea25",
"classlibcamera_1_1V4L2Device.html#a3dddbf60ff67bb5fbe9998609175ad0a",
"classlibcamera_1_1Vector.html#a2301ef72f51d28c21ce684cc582c709c",
"classlibcamera_1_1ipa_1_1Histogram.html#a8521136094a8f62785bbe3776d0635eb",
"functions_func_z.html",
"namespacelibcamera_1_1controls.html#a13ee7c9e1988f08f799b8d6d6056c0aa",
"namespacelibcamera_1_1properties.html#a557e0e1befdc2f7893c645910de4255e",
"structlibcamera_1_1StreamConfiguration.html#a4a814bad245d8ab33edb3ae0176bfb03",
"structlibcamera_1_1ipa__control__value__entry.html"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';

==> libcamera-docs-0.7.0-1-x86_64.pkg.tar.zst: usr/share/doc/libcamera/html/internal-api/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "libcamera", "index.html", [
    [ "libcamera internal API reference", "index.html", null ],
    [ "Reentrancy and Thread-Safety", "thread-safety.html", null ],
    [ "Thread Support", "thread.html", [
      [ "Threads and Objects", "thread.html#thread-objects", null ],
      [ "Threads and Signals", "thread.html#thread-signals", null ]
    ] ],
    [ "Camera Model", "camera-model.html", [
      [ "Pipeline Model", "camera-model.html#camera-pipeline-model", [
        [ "Camera Sensor Model", "camera-model.html#camera-sensor-model", null ],
        [ "Digital Zoom", "camera-model.html#digital-zoom", null ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ],
    [ "Thread Safety", "context.html", null ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", "namespacemembers_dup" ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ],
        [ "Typedefs", "namespacemembers_type.html", null ],
        [ "Enumerations", "namespacemembers_enum.html", null ],
        [ "Enumerator", "namespacemembers_eval.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Hierarchy", "hierarchy.html", "hierarchy" ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Functions", "functions_func.html", "functions_func" ],
        [ "Variables", "functions_vars.html", "functions_vars" ],
        [ "Typedefs", "functions_type.html", null ],
        [ "Enumerations", "functions_enum.html", null ],
        [ "Enumerator", "functions_eval.html", null ],
        [ "Related Symbols", "functions_rela.html", null ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "File Members", "globals.html", [
        [ "All", "globals.html", null ],
        [ "Macros", "globals_defs.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"af_8h.html",
"classlibcamera_1_1CameraLens.html#a6291cfc11479b7842cfb209789f7c45c",
"classlibcamera_1_1ControlInfoMap.html#a7d5d2891e3c6f24929a769499df98c5d",
"classlibcamera_1_1Debayer.html#a579fa6a49e82c6366dcaf7c54f6fbd93",
"classlibcamera_1_1EventNotifier.html#a83550c524a9bcc0ea582e876ca43c04d",
"classlibcamera_1_1IPAProxy.html#ae59a8a916c5e244be8bdd6860503886fa547f15ec7e7ee0b6e7983786b9794b70",
"classlibcamera_1_1MediaDevice.html#ac9128298434c9a142fd93539cd6a259d",
"classlibcamera_1_1PixelFormat.html#ad0dad4aa8a1ad2e6851ba677dfda259e",
"classlibcamera_1_1SharedFD.html#a7ed7ee6c08634cc971c93f5fb1984c59",
"classlibcamera_1_1ThreadData.html#a73c1e67e42753c538d7bfe7696019a35",
"classlibcamera_1_1V4L2VideoDevice.html#a154f5283d16ebd5e15d63e212745cb64",
"classlibcamera_1_1ipa_1_1AgcMeanLuminance.html#aaffc93f92dba52ab302ad086ae4824a5",
"classlibcamera_1_1ipa_1_1V4L2ParamsBlock.html#ac8dd6ecb39be74273890d17c70558b6c",
"ipa__proxy_8h_source.html",
"namespacelibcamera_1_1controls.html#a821c538ea150d8361ca4e499270bc201",
"structlibcamera_1_1CameraSensorProperties.html",
"structlibcamera_1_1V4L2PixelFormat_1_1Info.html#a3e5ae999933521ecc174b3c7afaf7f16"
];

var SYNCONMSG = 'click to disable panel synchronization';
var SYNCOFFMSG = 'click to enable panel synchronization';
var LISTOFALLMEMBERS = 'List of all members';
